@@ -17,14 +17,18 @@ DEFAULT_GDPR_FILES = [
     'mentions-legales-en',
 ]
 
+DEFAULT_COOKIES_FILES = [
+    'cookies-policy',
+    'cookies-policy-nl',
+    'cookies-policy-en',
+]
 
-@provider(IContextAwareDefaultFactory)
-def get_default_text(context):
+
+def get_text_from_view(view_name):
     """
     Text get from a browser view template <body> tag
     """
     portal = api.portal.get()
-    view_name = 'default_gdpr_text'
     request = getattr(portal, 'REQUEST', None)
     if request is not None:
         view = api.content.get_view(
@@ -38,3 +42,13 @@ def get_default_text(context):
                 text = text.decode("utf-8")
             return text
     return u''
+
+
+@provider(IContextAwareDefaultFactory)
+def get_default_text(context):
+    return get_text_from_view('default_gdpr_text')
+
+
+@provider(IContextAwareDefaultFactory)
+def get_default_cookies_text(context):
+    return get_text_from_view('default_cookies_text')
